@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
-our $DATE = '2016-10-11'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $DATE = '2017-03-09'; # DATE
+our $VERSION = '0.30'; # VERSION
 
 use strict;
 use warnings;
@@ -58,7 +58,7 @@ sub _system_or_readpipe_or_run {
     for (keys %$opts) {
         die "Unknown option '$_'"
             unless /\A(
-                        capture_stdout|capture_stderr|
+                        capture_stdout|capture_stderr|capture_merged|
                         chdir|dies?|dry_run|env|lang|log||max_log_output|shell|
                         stdin # XXX: only for run()
                     )\z/x;
@@ -120,6 +120,10 @@ sub _system_or_readpipe_or_run {
             require Capture::Tiny;
             (${ $opts->{capture_stdout} }, ${ $opts->{capture_stderr} }) =
                 &Capture::Tiny::capture($doit);
+        } elsif ($opts->{capture_merged}) {
+            require Capture::Tiny;
+            ${ $opts->{capture_merged} } =
+                &Capture::Tiny::capture_merged($doit);
         } elsif ($opts->{capture_stdout}) {
             require Capture::Tiny;
             ${ $opts->{capture_stdout} } =
@@ -323,6 +327,9 @@ sub _system_or_readpipe_or_run {
                 (ref($opts->{capture_stderr}) ?
                      ", captured stderr: <<" .
                      (defined ${$opts->{capture_stderr}} ? ${$opts->{capture_stderr}} : ''). ">>" : ""),
+                (ref($opts->{capture_merged}) ?
+                     ", captured merged: <<" .
+                     (defined ${$opts->{capture_merged}} ? ${$opts->{capture_merged}} : ''). ">>" : ""),
             );
             $log->error($msg) if $opts->{log};
             die $msg if $opt_die;
@@ -366,7 +373,7 @@ IPC::System::Options - Perl's system() and readpipe/qx replacement, with options
 
 =head1 VERSION
 
-This document describes version 0.29 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2016-10-11.
+This document describes version 0.30 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2017-03-09.
 
 =head1 SYNOPSIS
 
@@ -465,6 +472,11 @@ Capture stdout using L<Capture::Tiny>.
 
 Capture stderr using L<Capture::Tiny>.
 
+=item * capture_merged => scalarref
+
+Capture stdout and stderr in a single variable using L<Capture::Tiny>'s
+C<capture_merged>.
+
 =item * chdir => str
 
 Attempt to change to specified directory first and change back to the original
@@ -540,6 +552,10 @@ See option documentation in C<system()>.
 
 See option documentation in C<system()>.
 
+=item * capture_merged => scalarref
+
+See option documentation in C<system()>.
+
 =item * max_log_output => int
 
 If set, will limit result length being logged. It's a good idea to set this
@@ -585,6 +601,10 @@ See option documentation in C<system()>.
 
 See option documentation in C<system()>.
 
+=item * capture_merged => scalarref
+
+See option documentation in C<system()>.
+
 =item * stdin => scalar
 
 Supply standard input.
@@ -621,7 +641,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
